diff libpurple/protocols/qq/sys_msg.h @ 15822:32c366eeeb99

sed -ie 's/gaim/purple/g'
author Sean Egan <seanegan@gmail.com>
date Mon, 19 Mar 2007 07:01:17 +0000
parents 5fe8042783c1
children 44b4e8bd759b
line wrap: on
line diff
--- a/libpurple/protocols/qq/sys_msg.h	Mon Mar 19 06:11:46 2007 +0000
+++ b/libpurple/protocols/qq/sys_msg.h	Mon Mar 19 07:01:17 2007 +0000
@@ -1,9 +1,9 @@
 /**
  * @file sys_msg.h
  *
- * gaim
+ * purple
  *
  * Gaim is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.
  *
@@ -28,6 +28,6 @@
 #include <glib.h>
 #include "connection.h"
 
-void qq_process_msg_sys(guint8 *buf, gint buf_len, guint16 seq, GaimConnection *gc);
+void qq_process_msg_sys(guint8 *buf, gint buf_len, guint16 seq, PurpleConnection *gc);
 
 #endif
@@ -1,9 +1,9 @@
  *
- * Gaim is the legal property of its developers, whose names are too numerous
+ * Purple is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.